@@ -5,13 +5,13 @@
 /// ```
 /// use aoko::l;
 /// 
-/// l!(foo = 233; bar = 666);
+/// l!(foo = 233; bar: u16 = 666;);
 /// assert_eq!((233, 666), (foo, bar));
 /// ```
 #[macro_export]
 macro_rules! l {
-    ($($a:ident = $b:expr);*) => {
-        $(let $a = $b;)*
+    ($($a:ident $(:$t:ty)? = $b:expr);* $(;)?) => {
+        $(let $a $(:$t)? = $b;)*
     };
 }
 
@@ -22,14 +22,14 @@ macro_rules! l {
 /// ```
 /// use aoko::lm;
 /// 
-/// lm!(foo = 233; bar = 1024);
+/// lm!(foo = 233; bar: u16 = 1024;);
 /// foo = 666; bar = 2048;
 /// assert_eq!((666, 2048), (foo, bar));
 /// ```
 #[macro_export]
 macro_rules! lm {
-    ($($a:ident = $b:expr);*) => {
-        $(let mut $a = $b;)*
+    ($($a:ident $(:$t:ty)? = $b:expr);* $(;)?) => {
+        $(let mut $a $(:$t)? = $b;)*
     };
 }
 
@@ -45,12 +45,12 @@ macro_rules! lm {
 /// use aoko::swap;
 /// 
 /// let (a, b, c, d) = (1, 2, 3, 4);
-/// swap!(a, b; c, d);
+/// swap!(a, b; c, d;);
 /// assert_eq!((a, b, c, d), (2, 1, 4, 3));
 /// ```
 #[macro_export]
 macro_rules! swap {
-    ($($a:ident, $b:ident);*) => {
+    ($($a:ident, $b:ident);* $(;)?) => {
         $(let ($b, $a) = ($a, $b);)*
     };
 }
@@ -67,7 +67,7 @@ macro_rules! swap {
 /// use aoko::swap_mut;
 /// 
 /// let (a, b, c, d) = (1, 2, 3, 4);
-/// swap_mut!(a, b; c, d);
+/// swap_mut!(a, b; c, d;);
 /// assert_eq!((a, b, c, d), (2, 1, 4, 3));
 /// 
 /// a = 10; b = 20; c = 30; d = 40;
@@ -75,7 +75,7 @@ macro_rules! swap {
 /// ```
 #[macro_export]
 macro_rules! swap_mut {
-    ($($a:ident, $b:ident);*) => {
+    ($($a:ident, $b:ident);* $(;)?) => {
         $(let (mut $b, mut $a) = ($a, $b);)*
     };
 }
\ No newline at end of file
